// SPDX-License-Identifier: GPL-2.0-only
//
// Generated with linux-mdss-dsi-panel-driver-generator from vendor device tree:
//	Copyright (c) 2013, The Linux Foundation. All rights reserved.
// Copyright (c) 2024 Dzmitry Sankouski <dsankouski@gmail.com>

#include <linux/backlight.h>
#include <linux/delay.h>
#include <linux/gpio/consumer.h>
#include <linux/module.h>
#include <linux/of.h>
#include <linux/regulator/consumer.h>

#include <drm/display/drm_dsc.h>
#include <drm/display/drm_dsc_helper.h>
#include <drm/drm_mipi_dsi.h>
#include <drm/drm_probe_helper.h>
#include <drm/drm_panel.h>

#define S6E3HA8_NUM_STEPS 512

static u8 pac_aid_subdivision_data[S6E3HA8_NUM_STEPS][2] = {
	{ 0x0B, 0x76 },
	{ 0x0B, 0x75 },
	{ 0x0B, 0x73 },
	{ 0x0B, 0x71 },
	{ 0x0B, 0x6F },
	{ 0x0B, 0x6D },
	{ 0x0B, 0x63 },
	{ 0x0B, 0x62 },
	{ 0x0B, 0x5F },
	{ 0x0B, 0x5D },
	{ 0x0B, 0x53 },
	{ 0x0B, 0x51 },
	{ 0x0B, 0x4F },
	{ 0x0B, 0x4D },
	{ 0x0B, 0x44 },
	{ 0x0B, 0x43 },
	{ 0x0B, 0x41 },
	{ 0x0B, 0x3F },
	{ 0x0B, 0x3D },
	{ 0x0B, 0x33 },
	{ 0x0B, 0x31 },
	{ 0x0B, 0x30 },
	{ 0x0B, 0x2D },
	{ 0x0B, 0x23 },
	{ 0x0B, 0x21 },
	{ 0x0B, 0x1F },
	{ 0x0B, 0x1D },
	{ 0x0B, 0x13 },
	{ 0x0B, 0x12 },
	{ 0x0B, 0x0F },
	{ 0x0B, 0x0D },
	{ 0x0B, 0x03 },
	{ 0x0B, 0x01 },
	{ 0x0A, 0xFF },
	{ 0x0A, 0xFD },
	{ 0x0A, 0xF7 },
	{ 0x0A, 0xF3 },
	{ 0x0A, 0xF0 },
	{ 0x0A, 0xEC },
	{ 0x0A, 0xE8 },
	{ 0x0A, 0xE4 },
	{ 0x0A, 0xE0 },
	{ 0x0A, 0xDC },
	{ 0x0A, 0xD8 },
	{ 0x0A, 0xD3 },
	{ 0x0A, 0xCF },
	{ 0x0A, 0xCB },
	{ 0x0A, 0xC6 },
	{ 0x0A, 0xC2 },
	{ 0x0A, 0xBE },
	{ 0x0A, 0xB9 },
	{ 0x0A, 0xB5 },
	{ 0x0A, 0xB0 },
	{ 0x0A, 0xAC },
	{ 0x0A, 0xA7 },
	{ 0x0A, 0xA2 },
	{ 0x0A, 0x9E },
	{ 0x0A, 0x98 },
	{ 0x0A, 0x92 },
	{ 0x0A, 0x8C },
	{ 0x0A, 0x86 },
	{ 0x0A, 0x80 },
	{ 0x0A, 0x7A },
	{ 0x0A, 0x73 },
	{ 0x0A, 0x6D },
	{ 0x0A, 0x66 },
	{ 0x0A, 0x60 },
	{ 0x0A, 0x59 },
	{ 0x0A, 0x52 },
	{ 0x0A, 0x4C },
	{ 0x0A, 0x46 },
	{ 0x0A, 0x40 },
	{ 0x0A, 0x3A },
	{ 0x0A, 0x34 },
	{ 0x0A, 0x2E },
	{ 0x0A, 0x26 },
	{ 0x0A, 0x1F },
	{ 0x0A, 0x18 },
	{ 0x0A, 0x10 },
	{ 0x0A, 0x09 },
	{ 0x0A, 0x01 },
	{ 0x09, 0xF9 },
	{ 0x09, 0xF1 },
	{ 0x09, 0xEA },
	{ 0x09, 0xE2 },
	{ 0x09, 0xDA },
	{ 0x09, 0xD2 },
	{ 0x09, 0xCD },
	{ 0x09, 0xC8 },
	{ 0x09, 0xC2 },
	{ 0x09, 0xBD },
	{ 0x09, 0xB8 },
	{ 0x09, 0xB2 },
	{ 0x09, 0xAD },
	{ 0x09, 0xA7 },
	{ 0x09, 0xA2 },
	{ 0x09, 0x9D },
	{ 0x09, 0x98 },
	{ 0x09, 0x92 },
	{ 0x09, 0x8C },
	{ 0x09, 0x87 },
	{ 0x09, 0x82 },
	{ 0x09, 0x7D },
	{ 0x09, 0x78 },
	{ 0x09, 0x72 },
	{ 0x09, 0x6D },
	{ 0x09, 0x67 },
	{ 0x09, 0x62 },
	{ 0x09, 0x5C },
	{ 0x09, 0x57 },
	{ 0x09, 0x52 },
	{ 0x09, 0x4D },
	{ 0x09, 0x48 },
	{ 0x09, 0x43 },
	{ 0x09, 0x3E },
	{ 0x09, 0x39 },
	{ 0x09, 0x34 },
	{ 0x09, 0x2F },
	{ 0x09, 0x2A },
	{ 0x09, 0x25 },
	{ 0x09, 0x20 },
	{ 0x09, 0x1B },
	{ 0x09, 0x15 },
	{ 0x09, 0x0B },
	{ 0x09, 0x02 },
	{ 0x08, 0xF8 },
	{ 0x08, 0xEE },
	{ 0x08, 0xE4 },
	{ 0x08, 0xDB },
	{ 0x08, 0xD2 },
	{ 0x08, 0xCD },
	{ 0x08, 0xC8 },
	{ 0x08, 0xC3 },
	{ 0x08, 0xBE },
	{ 0x08, 0xB9 },
	{ 0x08, 0xB4 },
	{ 0x08, 0xAA },
	{ 0x08, 0xA1 },
	{ 0x08, 0x97 },
	{ 0x08, 0x8E },
	{ 0x08, 0x84 },
	{ 0x08, 0x7B },
	{ 0x08, 0x72 },
	{ 0x08, 0x6D },
	{ 0x08, 0x68 },
	{ 0x08, 0x63 },
	{ 0x08, 0x5D },
	{ 0x08, 0x58 },
	{ 0x08, 0x53 },
	{ 0x08, 0x49 },
	{ 0x08, 0x3F },
	{ 0x08, 0x36 },
	{ 0x08, 0x2C },
	{ 0x08, 0x23 },
	{ 0x08, 0x19 },
	{ 0x08, 0x0E },
	{ 0x08, 0x04 },
	{ 0x07, 0xFB },
	{ 0x07, 0xF2 },
	{ 0x07, 0xE8 },
	{ 0x07, 0xDF },
	{ 0x07, 0xD5 },
	{ 0x07, 0xCD },
	{ 0x07, 0xC4 },
	{ 0x07, 0xBA },
	{ 0x07, 0xB1 },
	{ 0x07, 0xA7 },
	{ 0x07, 0x9E },
	{ 0x07, 0x94 },
	{ 0x07, 0x8C },
	{ 0x07, 0x82 },
	{ 0x07, 0x78 },
	{ 0x07, 0x6E },
	{ 0x07, 0x64 },
	{ 0x07, 0x5A },
	{ 0x07, 0x50 },
	{ 0x07, 0x45 },
	{ 0x07, 0x3A },
	{ 0x07, 0x2F },
	{ 0x07, 0x24 },
	{ 0x07, 0x1A },
	{ 0x07, 0x0E },
	{ 0x07, 0x01 },
	{ 0x06, 0xF4 },
	{ 0x06, 0xE7 },
	{ 0x06, 0xDB },
	{ 0x06, 0xCE },
	{ 0x06, 0xC0 },
	{ 0x06, 0xB4 },
	{ 0x06, 0xA8 },
	{ 0x06, 0x9B },
	{ 0x06, 0x8F },
	{ 0x06, 0x83 },
	{ 0x06, 0x77 },
	{ 0x06, 0x6C },
	{ 0x06, 0x5F },
	{ 0x06, 0x52 },
	{ 0x06, 0x45 },
	{ 0x06, 0x38 },
	{ 0x06, 0x2B },
	{ 0x06, 0x1E },
	{ 0x06, 0x12 },
	{ 0x06, 0x01 },
	{ 0x05, 0xF0 },
	{ 0x05, 0xE0 },
	{ 0x05, 0xCF },
	{ 0x05, 0xBE },
	{ 0x05, 0xAD },
	{ 0x05, 0x9E },
	{ 0x05, 0x91 },
	{ 0x05, 0x84 },
	{ 0x05, 0x77 },
	{ 0x05, 0x6A },
	{ 0x05, 0x5D },
	{ 0x05, 0x50 },
	{ 0x05, 0x44 },
	{ 0x05, 0x33 },
	{ 0x05, 0x22 },
	{ 0x05, 0x11 },
	{ 0x05, 0x01 },
	{ 0x04, 0xF0 },
	{ 0x04, 0xDF },
	{ 0x04, 0xD0 },
	{ 0x04, 0xD3 },
	{ 0x04, 0xC5 },
	{ 0x04, 0xB7 },
	{ 0x04, 0xA9 },
	{ 0x04, 0x9B },
	{ 0x04, 0x8D },
	{ 0x04, 0x80 },
	{ 0x04, 0xE7 },
	{ 0x04, 0xD5 },
	{ 0x04, 0xC4 },
	{ 0x04, 0xB3 },
	{ 0x04, 0xA1 },
	{ 0x04, 0x90 },
	{ 0x04, 0x80 },
	{ 0x04, 0xE1 },
	{ 0x04, 0xD0 },
	{ 0x04, 0xC0 },
	{ 0x04, 0xAF },
	{ 0x04, 0x9F },
	{ 0x04, 0x8F },
	{ 0x04, 0x80 },
	{ 0x04, 0xDB },
	{ 0x04, 0xCC },
	{ 0x04, 0xBC },
	{ 0x04, 0xAD },
	{ 0x04, 0x9D },
	{ 0x04, 0x8E },
	{ 0x04, 0x80 },
	{ 0x04, 0xD8 },
	{ 0x04, 0xCB },
	{ 0x04, 0xBF },
	{ 0x04, 0xB2 },
	{ 0x04, 0xA6 },
	{ 0x04, 0x99 },
	{ 0x04, 0x8D },
	{ 0x04, 0x80 },
	{ 0x04, 0xE7 },
	{ 0x04, 0xD8 },
	{ 0x04, 0xCA },
	{ 0x04, 0xBB },
	{ 0x04, 0xAC },
	{ 0x04, 0x9D },
	{ 0x04, 0x8F },
	{ 0x04, 0x80 },
	{ 0x04, 0xE1 },
	{ 0x04, 0xD3 },
	{ 0x04, 0xC5 },
	{ 0x04, 0xB7 },
	{ 0x04, 0xAA },
	{ 0x04, 0x9C },
	{ 0x04, 0x8E },
	{ 0x04, 0x80 },
	{ 0x04, 0xDB },
	{ 0x04, 0xCE },
	{ 0x04, 0xC1 },
	{ 0x04, 0xB4 },
	{ 0x04, 0xA7 },
	{ 0x04, 0x9A },
	{ 0x04, 0x8D },
	{ 0x04, 0x80 },
	{ 0x04, 0xE6 },
	{ 0x04, 0xD8 },
	{ 0x04, 0xC9 },
	{ 0x04, 0xBB },
	{ 0x04, 0xAC },
	{ 0x04, 0x9D },
	{ 0x04, 0x8F },
	{ 0x04, 0x80 },
	{ 0x04, 0xE2 },
	{ 0x04, 0xD6 },
	{ 0x04, 0xCA },
	{ 0x04, 0xBE },
	{ 0x04, 0xB2 },
	{ 0x04, 0xA5 },
	{ 0x04, 0x99 },
	{ 0x04, 0x8D },
	{ 0x04, 0x80 },
	{ 0x04, 0xDC },
	{ 0x04, 0xD1 },
	{ 0x04, 0xC6 },
	{ 0x04, 0xBA },
	{ 0x04, 0xAF },
	{ 0x04, 0xA3 },
	{ 0x04, 0x98 },
	{ 0x04, 0x8D },
	{ 0x04, 0x80 },
	{ 0x04, 0xE5 },
	{ 0x04, 0xD9 },
	{ 0x04, 0xCC },
	{ 0x04, 0xC0 },
	{ 0x04, 0xB3 },
	{ 0x04, 0xA7 },
	{ 0x04, 0x9A },
	{ 0x04, 0x8E },
	{ 0x04, 0x80 },
	{ 0x04, 0xDE },
	{ 0x04, 0xD0 },
	{ 0x04, 0xC3 },
	{ 0x04, 0xB6 },
	{ 0x04, 0xA8 },
	{ 0x04, 0x9B },
	{ 0x04, 0x8D },
	{ 0x04, 0x80 },
	{ 0x04, 0xE6 },
	{ 0x04, 0xD9 },
	{ 0x04, 0xCD },
	{ 0x04, 0xC0 },
	{ 0x04, 0xB4 },
	{ 0x04, 0xA7 },
	{ 0x04, 0x9A },
	{ 0x04, 0x8E },
	{ 0x04, 0x80 },
	{ 0x04, 0xE1 },
	{ 0x04, 0xD6 },
	{ 0x04, 0xCC },
	{ 0x04, 0xC1 },
	{ 0x04, 0xB6 },
	{ 0x04, 0xAB },
	{ 0x04, 0xA0 },
	{ 0x04, 0x96 },
	{ 0x04, 0x8B },
	{ 0x04, 0x80 },
	{ 0x04, 0xE5 },
	{ 0x04, 0xD9 },
	{ 0x04, 0xCC },
	{ 0x04, 0xC0 },
	{ 0x04, 0xB3 },
	{ 0x04, 0xA7 },
	{ 0x04, 0x9A },
	{ 0x04, 0x8E },
	{ 0x04, 0x80 },
	{ 0x04, 0xE0 },
	{ 0x04, 0xD6 },
	{ 0x04, 0xCB },
	{ 0x04, 0xC0 },
	{ 0x04, 0xB6 },
	{ 0x04, 0xAB },
	{ 0x04, 0xA0 },
	{ 0x04, 0x96 },
	{ 0x04, 0x8B },
	{ 0x04, 0x80 },
	{ 0x04, 0xE5 },
	{ 0x04, 0xD9 },
	{ 0x04, 0xCE },
	{ 0x04, 0xC3 },
	{ 0x04, 0xB8 },
	{ 0x04, 0xAD },
	{ 0x04, 0xA2 },
	{ 0x04, 0x96 },
	{ 0x04, 0x8B },
	{ 0x04, 0x80 },
	{ 0x04, 0xDE },
	{ 0x04, 0xD4 },
	{ 0x04, 0xCB },
	{ 0x04, 0xC1 },
	{ 0x04, 0xB8 },
	{ 0x04, 0xAF },
	{ 0x04, 0xA5 },
	{ 0x04, 0x9C },
	{ 0x04, 0x92 },
	{ 0x04, 0x89 },
	{ 0x04, 0x7E },
	{ 0x04, 0x6C },
	{ 0x04, 0x59 },
	{ 0x04, 0x46 },
	{ 0x04, 0x34 },
	{ 0x04, 0x21 },
	{ 0x04, 0x0E },
	{ 0x03, 0xFC },
	{ 0x03, 0xE9 },
	{ 0x03, 0xD7 },
	{ 0x03, 0xC4 },
	{ 0x03, 0xB2 },
	{ 0x03, 0x9F },
	{ 0x03, 0x8D },
	{ 0x03, 0x7A },
	{ 0x03, 0x65 },
	{ 0x03, 0x4F },
	{ 0x03, 0x3A },
	{ 0x03, 0x24 },
	{ 0x03, 0x0F },
	{ 0x02, 0xFA },
	{ 0x02, 0xE4 },
	{ 0x02, 0xCE },
	{ 0x02, 0xB7 },
	{ 0x02, 0xA1 },
	{ 0x02, 0x8A },
	{ 0x02, 0x74 },
	{ 0x02, 0x5D },
	{ 0x02, 0x46 },
	{ 0x02, 0x30 },
	{ 0x02, 0x02 },
	{ 0x01, 0xEF },
	{ 0x01, 0xDC },
	{ 0x01, 0xC9 },
	{ 0x01, 0xB6 },
	{ 0x01, 0xA2 },
	{ 0x01, 0x8F },
	{ 0x01, 0x7C },
	{ 0x02, 0x0E },
	{ 0x01, 0xFC },
	{ 0x01, 0xEA },
	{ 0x01, 0xD7 },
	{ 0x01, 0xC5 },
	{ 0x01, 0xB3 },
	{ 0x01, 0xA0 },
	{ 0x01, 0x8E },
	{ 0x01, 0x7C },
	{ 0x02, 0x06 },
	{ 0x01, 0xF4 },
	{ 0x01, 0xE3 },
	{ 0x01, 0xD2 },
	{ 0x01, 0xC1 },
	{ 0x01, 0xAF },
	{ 0x01, 0x9E },
	{ 0x01, 0x8D },
	{ 0x01, 0x7C },
	{ 0x02, 0x07 },
	{ 0x01, 0xF8 },
	{ 0x01, 0xE8 },
	{ 0x01, 0xD9 },
	{ 0x01, 0xC9 },
	{ 0x01, 0xBA },
	{ 0x01, 0xAA },
	{ 0x01, 0x9B },
	{ 0x01, 0x8B },
	{ 0x01, 0x7C },
	{ 0x01, 0xED },
	{ 0x01, 0xDD },
	{ 0x01, 0xCD },
	{ 0x01, 0xBD },
	{ 0x01, 0xAD },
	{ 0x01, 0x9C },
	{ 0x01, 0x8C },
	{ 0x01, 0x7C },
	{ 0x01, 0xF1 },
	{ 0x01, 0xE2 },
	{ 0x01, 0xD3 },
	{ 0x01, 0xC5 },
	{ 0x01, 0xB6 },
	{ 0x01, 0xA8 },
	{ 0x01, 0x99 },
	{ 0x01, 0x8A },
	{ 0x01, 0x7C },
	{ 0x01, 0xEB },
	{ 0x01, 0xDD },
	{ 0x01, 0xCF },
	{ 0x01, 0xC1 },
	{ 0x01, 0xB3 },
	{ 0x01, 0xA6 },
	{ 0x01, 0x98 },
	{ 0x01, 0x8A },
	{ 0x01, 0x7C },
	{ 0x01, 0xA4 },
	{ 0x01, 0x97 },
	{ 0x01, 0x89 },
	{ 0x01, 0x7C },
	{ 0x01, 0xA1 },
	{ 0x01, 0x94 },
	{ 0x01, 0x87 },
	{ 0x01, 0x7A },
	{ 0x01, 0x65 },
	{ 0x01, 0x50 },
	{ 0x01, 0x3B },
	{ 0x01, 0x2C },
	{ 0x01, 0x1D },
	{ 0x01, 0x0E },
	{ 0x00, 0xFF },
	{ 0x00, 0xEB },
	{ 0x00, 0xD7 },
	{ 0x00, 0xC3 },
	{ 0x00, 0xAF },
	{ 0x00, 0x91 },
	{ 0x00, 0x73 },
	{ 0x00, 0x55 },
	{ 0x00, 0x37 },
	{ 0x00, 0x3A },
	{ 0x00, 0x2B },
	{ 0x00, 0x1B },
	{ 0x00, 0x0C },
	{ 0x00, 0x39 },
	{ 0x00, 0x2A },
	{ 0x00, 0x1B },
	{ 0x00, 0x0C },
	{ 0x00, 0x39 },
	{ 0x00, 0x2A },
	{ 0x00, 0x1B },
	{ 0x00, 0x0C },
	{ 0x00, 0x0C },
};

static u8 irc_data[S6E3HA8_NUM_STEPS][36] = {
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x00, 0x00, 0x00, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x00, 0x00, 0x00, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x00, 0x00, 0x00, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x00, 0x00, 0x00, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x00, 0x00, 0x00, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x00, 0x00, 0x00, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x03, 0x03, 0x03, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x04, 0x04, 0x04, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x05, 0x05, 0x05, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x06, 0x06, 0x06, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x06, 0x06, 0x06, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x06, 0x06, 0x06, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x06, 0x06, 0x06, 0x02, 0x02, 0x02, 0x01, 0x01, 0x01, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x06, 0x06, 0x06, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x06, 0x06, 0x06, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x06, 0x06, 0x06, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x06, 0x06, 0x06, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x06, 0x06, 0x06, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x06, 0x06, 0x06, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x06, 0x06, 0x06, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x06, 0x06, 0x06, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x06, 0x06, 0x06, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x06, 0x06, 0x06, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x06, 0x06, 0x06, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x06, 0x06, 0x06, 0x02, 0x02, 0x02, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x06, 0x06, 0x06, 0x03, 0x03, 0x03, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x06, 0x06, 0x06, 0x03, 0x03, 0x03, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x07, 0x07, 0x07, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x07, 0x07, 0x07, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x07, 0x07, 0x07, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x07, 0x07, 0x07, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x07, 0x07, 0x07, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x07, 0x07, 0x07, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x07, 0x07, 0x07, 0x02, 0x02, 0x02, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x07, 0x07, 0x07, 0x02, 0x02, 0x02, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x07, 0x07, 0x07, 0x02, 0x02, 0x02, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x07, 0x07, 0x07, 0x03, 0x03, 0x03, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x07, 0x07, 0x07, 0x03, 0x03, 0x03, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x07, 0x07, 0x07, 0x03, 0x03, 0x03, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x07, 0x07, 0x07, 0x03, 0x03, 0x03, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x07, 0x07, 0x07, 0x03, 0x03, 0x03, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x07, 0x07, 0x07, 0x03, 0x03, 0x03, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x07, 0x07, 0x07, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x08, 0x08, 0x08, 0x02, 0x02, 0x02, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x08, 0x08, 0x08, 0x02, 0x02, 0x02, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x08, 0x08, 0x08, 0x02, 0x02, 0x02, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x08, 0x08, 0x08, 0x02, 0x02, 0x02, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x08, 0x08, 0x08, 0x03, 0x03, 0x03, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x08, 0x08, 0x08, 0x03, 0x03, 0x03, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x08, 0x08, 0x08, 0x03, 0x03, 0x03, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x08, 0x08, 0x08, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x08, 0x08, 0x08, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x08, 0x08, 0x08, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x08, 0x08, 0x08, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x08, 0x08, 0x08, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x09, 0x09, 0x09, 0x02, 0x02, 0x02, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x02, 0x02, 0x02, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x09, 0x09, 0x09, 0x04, 0x04, 0x04, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x09, 0x09, 0x09, 0x04, 0x04, 0x04, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0A, 0x0A, 0x0A, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0A, 0x0A, 0x0A, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0A, 0x0A, 0x0A, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0A, 0x0A, 0x0A, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0A, 0x0A, 0x0A, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0A, 0x0A, 0x0A, 0x03, 0x03, 0x03, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0A, 0x0A, 0x0A, 0x03, 0x03, 0x03, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0A, 0x0A, 0x0A, 0x04, 0x04, 0x04, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0A, 0x0A, 0x0A, 0x04, 0x04, 0x04, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0A, 0x0A, 0x0A, 0x04, 0x04, 0x04, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0A, 0x0A, 0x0A, 0x04, 0x04, 0x04, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0A, 0x0A, 0x0A, 0x04, 0x04, 0x04, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0B, 0x0B, 0x0B, 0x03, 0x03, 0x03, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0B, 0x0B, 0x0B, 0x03, 0x03, 0x03, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0B, 0x0B, 0x0B, 0x03, 0x03, 0x03, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0B, 0x0B, 0x0B, 0x03, 0x03, 0x03, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0B, 0x0B, 0x0B, 0x04, 0x04, 0x04, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0B, 0x0B, 0x0B, 0x04, 0x04, 0x04, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0B, 0x0B, 0x0B, 0x04, 0x04, 0x04, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0B, 0x0B, 0x0B, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0B, 0x0B, 0x0B, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0B, 0x0B, 0x0B, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0B, 0x0B, 0x0B, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0C, 0x0C, 0x0C, 0x04, 0x04, 0x04, 0x03, 0x03, 0x03, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0C, 0x0C, 0x0C, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0C, 0x0C, 0x0C, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0C, 0x0C, 0x0C, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0C, 0x0C, 0x0C, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0C, 0x0C, 0x0C, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0C, 0x0C, 0x0C, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0C, 0x0C, 0x0C, 0x05, 0x05, 0x05, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0C, 0x0C, 0x0C, 0x05, 0x05, 0x05, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0D, 0x0D, 0x0D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0D, 0x0D, 0x0D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0D, 0x0D, 0x0D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0D, 0x0D, 0x0D, 0x04, 0x04, 0x04, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0D, 0x0D, 0x0D, 0x04, 0x04, 0x04, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0D, 0x0D, 0x0D, 0x05, 0x05, 0x05, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0D, 0x0D, 0x0D, 0x05, 0x05, 0x05, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0D, 0x0D, 0x0D, 0x05, 0x05, 0x05, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0D, 0x0D, 0x0D, 0x05, 0x05, 0x05, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0D, 0x0D, 0x0D, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0E, 0x0E, 0x0E, 0x04, 0x04, 0x04, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0E, 0x0E, 0x0E, 0x04, 0x04, 0x04, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0E, 0x0E, 0x0E, 0x04, 0x04, 0x04, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0E, 0x0E, 0x0E, 0x05, 0x05, 0x05, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0E, 0x0E, 0x0E, 0x05, 0x05, 0x05, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0E, 0x0E, 0x0E, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0E, 0x0E, 0x0E, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0E, 0x0E, 0x0E, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0E, 0x0E, 0x0E, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0F, 0x0F, 0x0F, 0x05, 0x05, 0x05, 0x04, 0x04, 0x04, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0F, 0x0F, 0x0F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0F, 0x0F, 0x0F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0F, 0x0F, 0x0F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0F, 0x0F, 0x0F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0F, 0x0F, 0x0F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0F, 0x0F, 0x0F, 0x06, 0x06, 0x06, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x0F, 0x0F, 0x0F, 0x06, 0x06, 0x06, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x10, 0x10, 0x10, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x10, 0x10, 0x10, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x10, 0x10, 0x10, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x10, 0x10, 0x10, 0x05, 0x05, 0x05, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x10, 0x10, 0x10, 0x05, 0x05, 0x05, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x10, 0x10, 0x10, 0x06, 0x06, 0x06, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x10, 0x10, 0x10, 0x06, 0x06, 0x06, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x10, 0x10, 0x10, 0x06, 0x06, 0x06, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x10, 0x10, 0x10, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x11, 0x11, 0x11, 0x05, 0x05, 0x05, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x11, 0x11, 0x11, 0x05, 0x05, 0x05, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x11, 0x11, 0x11, 0x06, 0x06, 0x06, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x11, 0x11, 0x11, 0x06, 0x06, 0x06, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x11, 0x11, 0x11, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x11, 0x11, 0x11, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x11, 0x11, 0x11, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x12, 0x12, 0x12, 0x06, 0x06, 0x06, 0x05, 0x05, 0x05, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x12, 0x12, 0x12, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x12, 0x12, 0x12, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x12, 0x12, 0x12, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x12, 0x12, 0x12, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x12, 0x12, 0x12, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x12, 0x12, 0x12, 0x07, 0x07, 0x07, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x12, 0x12, 0x12, 0x07, 0x07, 0x07, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x13, 0x13, 0x13, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x13, 0x13, 0x13, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x13, 0x13, 0x13, 0x06, 0x06, 0x06, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x13, 0x13, 0x13, 0x07, 0x07, 0x07, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x13, 0x13, 0x13, 0x07, 0x07, 0x07, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x13, 0x13, 0x13, 0x07, 0x07, 0x07, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x13, 0x13, 0x13, 0x07, 0x07, 0x07, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x14, 0x14, 0x14, 0x06, 0x06, 0x06, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x14, 0x14, 0x14, 0x06, 0x06, 0x06, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x14, 0x14, 0x14, 0x07, 0x07, 0x07, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x14, 0x14, 0x14, 0x07, 0x07, 0x07, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x14, 0x14, 0x14, 0x07, 0x07, 0x07, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x14, 0x14, 0x14, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x14, 0x14, 0x14, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x14, 0x14, 0x14, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x15, 0x15, 0x15, 0x07, 0x07, 0x07, 0x06, 0x06, 0x06, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x15, 0x15, 0x15, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x15, 0x15, 0x15, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x15, 0x15, 0x15, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x15, 0x15, 0x15, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x15, 0x15, 0x15, 0x08, 0x08, 0x08, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x15, 0x15, 0x15, 0x08, 0x08, 0x08, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x16, 0x16, 0x16, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x16, 0x16, 0x16, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x16, 0x16, 0x16, 0x07, 0x07, 0x07, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x16, 0x16, 0x16, 0x08, 0x08, 0x08, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x16, 0x16, 0x16, 0x08, 0x08, 0x08, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x16, 0x16, 0x16, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x17, 0x17, 0x17, 0x07, 0x07, 0x07, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x17, 0x17, 0x17, 0x08, 0x08, 0x08, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x17, 0x17, 0x17, 0x08, 0x08, 0x08, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x17, 0x17, 0x17, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x17, 0x17, 0x17, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x17, 0x17, 0x17, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x18, 0x18, 0x18, 0x08, 0x08, 0x08, 0x07, 0x07, 0x07, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x18, 0x18, 0x18, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x18, 0x18, 0x18, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x18, 0x18, 0x18, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x18, 0x18, 0x18, 0x09, 0x09, 0x09, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x18, 0x18, 0x18, 0x09, 0x09, 0x09, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x19, 0x19, 0x19, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x19, 0x19, 0x19, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x19, 0x19, 0x19, 0x08, 0x08, 0x08, 0x09, 0x09, 0x09, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x19, 0x19, 0x19, 0x09, 0x09, 0x09, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x19, 0x19, 0x19, 0x09, 0x09, 0x09, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x19, 0x19, 0x19, 0x09, 0x09, 0x09, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1A, 0x1A, 0x1A, 0x08, 0x08, 0x08, 0x09, 0x09, 0x09, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1A, 0x1A, 0x1A, 0x08, 0x08, 0x08, 0x09, 0x09, 0x09, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1A, 0x1A, 0x1A, 0x09, 0x09, 0x09, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1A, 0x1A, 0x1A, 0x09, 0x09, 0x09, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1A, 0x1A, 0x1A, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1A, 0x1A, 0x1A, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1B, 0x1B, 0x1B, 0x09, 0x09, 0x09, 0x08, 0x08, 0x08, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1B, 0x1B, 0x1B, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1B, 0x1B, 0x1B, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1B, 0x1B, 0x1B, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1B, 0x1B, 0x1B, 0x0A, 0x0A, 0x0A, 0x09, 0x09, 0x09, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1C, 0x1C, 0x1C, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1C, 0x1C, 0x1C, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1C, 0x1C, 0x1C, 0x09, 0x09, 0x09, 0x0A, 0x0A, 0x0A, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1C, 0x1C, 0x1C, 0x0A, 0x0A, 0x0A, 0x09, 0x09, 0x09, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1C, 0x1C, 0x1C, 0x0A, 0x0A, 0x0A, 0x09, 0x09, 0x09, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1C, 0x1C, 0x1C, 0x0A, 0x0A, 0x0A, 0x09, 0x09, 0x09, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1D, 0x1D, 0x1D, 0x09, 0x09, 0x09, 0x0A, 0x0A, 0x0A, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1D, 0x1D, 0x1D, 0x0A, 0x0A, 0x0A, 0x09, 0x09, 0x09, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1D, 0x1D, 0x1D, 0x0A, 0x0A, 0x0A, 0x09, 0x09, 0x09, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1D, 0x1D, 0x1D, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1D, 0x1D, 0x1D, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1D, 0x1D, 0x1D, 0x0B, 0x0B, 0x0B, 0x09, 0x09, 0x09, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1E, 0x1E, 0x1E, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1E, 0x1E, 0x1E, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1E, 0x1E, 0x1E, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1E, 0x1E, 0x1E, 0x0B, 0x0B, 0x0B, 0x09, 0x09, 0x09, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1E, 0x1E, 0x1E, 0x0B, 0x0B, 0x0B, 0x0A, 0x0A, 0x0A, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1F, 0x1F, 0x1F, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1F, 0x1F, 0x1F, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1F, 0x1F, 0x1F, 0x0B, 0x0B, 0x0B, 0x0A, 0x0A, 0x0A, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1F, 0x1F, 0x1F, 0x0B, 0x0B, 0x0B, 0x0A, 0x0A, 0x0A, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x1F, 0x1F, 0x1F, 0x0B, 0x0B, 0x0B, 0x0A, 0x0A, 0x0A, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x20, 0x20, 0x20, 0x0A, 0x0A, 0x0A, 0x0B, 0x0B, 0x0B, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x20, 0x20, 0x20, 0x0B, 0x0B, 0x0B, 0x0A, 0x0A, 0x0A, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x20, 0x20, 0x20, 0x0B, 0x0B, 0x0B, 0x0A, 0x0A, 0x0A, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x20, 0x20, 0x20, 0x0B, 0x0B, 0x0B, 0x0A, 0x0A, 0x0A, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x20, 0x20, 0x20, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x20, 0x20, 0x20, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x21, 0x21, 0x21, 0x0B, 0x0B, 0x0B, 0x0A, 0x0A, 0x0A, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x21, 0x21, 0x21, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x21, 0x21, 0x21, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x21, 0x21, 0x21, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x21, 0x21, 0x21, 0x0C, 0x0C, 0x0C, 0x0B, 0x0B, 0x0B, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x22, 0x22, 0x22, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x22, 0x22, 0x22, 0x0C, 0x0C, 0x0C, 0x0B, 0x0B, 0x0B, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x22, 0x22, 0x22, 0x0C, 0x0C, 0x0C, 0x0B, 0x0B, 0x0B, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x23, 0x23, 0x23, 0x0B, 0x0B, 0x0B, 0x0C, 0x0C, 0x0C, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x23, 0x23, 0x23, 0x0C, 0x0C, 0x0C, 0x0B, 0x0B, 0x0B, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x23, 0x23, 0x23, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x23, 0x23, 0x23, 0x0D, 0x0D, 0x0D, 0x0B, 0x0B, 0x0B, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x24, 0x24, 0x24, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x24, 0x24, 0x24, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x24, 0x24, 0x24, 0x0D, 0x0D, 0x0D, 0x0C, 0x0C, 0x0C, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x25, 0x25, 0x25, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x25, 0x25, 0x25, 0x0D, 0x0D, 0x0D, 0x0C, 0x0C, 0x0C, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x25, 0x25, 0x25, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x26, 0x26, 0x26, 0x0D, 0x0D, 0x0D, 0x0C, 0x0C, 0x0C, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x26, 0x26, 0x26, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x26, 0x26, 0x26, 0x0E, 0x0E, 0x0E, 0x0C, 0x0C, 0x0C, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x27, 0x27, 0x27, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x27, 0x27, 0x27, 0x0E, 0x0E, 0x0E, 0x0C, 0x0C, 0x0C, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x28, 0x28, 0x28, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x28, 0x28, 0x28, 0x0E, 0x0E, 0x0E, 0x0D, 0x0D, 0x0D, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x28, 0x28, 0x28, 0x0E, 0x0E, 0x0E, 0x0D, 0x0D, 0x0D, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x29, 0x29, 0x29, 0x0D, 0x0D, 0x0D, 0x0E, 0x0E, 0x0E, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x29, 0x29, 0x29, 0x0E, 0x0E, 0x0E, 0x0D, 0x0D, 0x0D, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x29, 0x29, 0x29, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x29, 0x29, 0x29, 0x0F, 0x0F, 0x0F, 0x0D, 0x0D, 0x0D, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x2A, 0x2A, 0x2A, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x2A, 0x2A, 0x2A, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x2A, 0x2A, 0x2A, 0x0F, 0x0F, 0x0F, 0x0E, 0x0E, 0x0E, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x2B, 0x2B, 0x2B, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x2B, 0x2B, 0x2B, 0x0F, 0x0F, 0x0F, 0x0E, 0x0E, 0x0E, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x2B, 0x2B, 0x2B, 0x0F, 0x0F, 0x0F, 0x0E, 0x0E, 0x0E, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x2C, 0x2C, 0x2C, 0x0F, 0x0F, 0x0F, 0x0E, 0x0E, 0x0E, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x2C, 0x2C, 0x2C, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x2C, 0x2C, 0x2C, 0x10, 0x10, 0x10, 0x0E, 0x0E, 0x0E, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x2D, 0x2D, 0x2D, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x2D, 0x2D, 0x2D, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x2D, 0x2D, 0x2D, 0x10, 0x10, 0x10, 0x0F, 0x0F, 0x0F, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x2E, 0x2E, 0x2E, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x2E, 0x2E, 0x2E, 0x10, 0x10, 0x10, 0x0F, 0x0F, 0x0F, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x2E, 0x2E, 0x2E, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x2F, 0x2F, 0x2F, 0x10, 0x10, 0x10, 0x0F, 0x0F, 0x0F, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x2F, 0x2F, 0x2F, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x2F, 0x2F, 0x2F, 0x11, 0x11, 0x11, 0x0F, 0x0F, 0x0F, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x30, 0x30, 0x30, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x30, 0x30, 0x30, 0x11, 0x11, 0x11, 0x0F, 0x0F, 0x0F, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x30, 0x30, 0x30, 0x11, 0x11, 0x11, 0x10, 0x10, 0x10, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x31, 0x31, 0x31, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x31, 0x31, 0x31, 0x11, 0x11, 0x11, 0x10, 0x10, 0x10, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x31, 0x31, 0x31, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x32, 0x32, 0x32, 0x11, 0x11, 0x11, 0x10, 0x10, 0x10, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x32, 0x32, 0x32, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x32, 0x32, 0x32, 0x12, 0x12, 0x12, 0x10, 0x10, 0x10, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x33, 0x33, 0x33, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x33, 0x33, 0x33, 0x12, 0x12, 0x12, 0x10, 0x10, 0x10, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x33, 0x33, 0x33, 0x12, 0x12, 0x12, 0x11, 0x11, 0x11, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x34, 0x34, 0x34, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x34, 0x34, 0x34, 0x12, 0x12, 0x12, 0x11, 0x11, 0x11, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x34, 0x34, 0x34, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x35, 0x35, 0x35, 0x12, 0x12, 0x12, 0x11, 0x11, 0x11, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x35, 0x35, 0x35, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x35, 0x35, 0x35, 0x13, 0x13, 0x13, 0x11, 0x11, 0x11, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x36, 0x36, 0x36, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x36, 0x36, 0x36, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x36, 0x36, 0x36, 0x13, 0x13, 0x13, 0x12, 0x12, 0x12, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x37, 0x37, 0x37, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x37, 0x37, 0x37, 0x13, 0x13, 0x13, 0x12, 0x12, 0x12, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x37, 0x37, 0x37, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x38, 0x38, 0x38, 0x13, 0x13, 0x13, 0x12, 0x12, 0x12, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x38, 0x38, 0x38, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x38, 0x38, 0x38, 0x14, 0x14, 0x14, 0x12, 0x12, 0x12, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x39, 0x39, 0x39, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x39, 0x39, 0x39, 0x14, 0x14, 0x14, 0x13, 0x13, 0x13, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x3A, 0x3A, 0x3A, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x3A, 0x3A, 0x3A, 0x14, 0x14, 0x14, 0x13, 0x13, 0x13, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x3A, 0x3A, 0x3A, 0x14, 0x14, 0x14, 0x13, 0x13, 0x13, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x3B, 0x3B, 0x3B, 0x14, 0x14, 0x14, 0x13, 0x13, 0x13, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x3B, 0x3B, 0x3B, 0x14, 0x14, 0x14, 0x13, 0x13, 0x13, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x3B, 0x3B, 0x3B, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x3C, 0x3C, 0x3C, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x3C, 0x3C, 0x3C, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x3C, 0x3C, 0x3C, 0x15, 0x15, 0x15, 0x14, 0x14, 0x14, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x3D, 0x3D, 0x3D, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x3D, 0x3D, 0x3D, 0x15, 0x15, 0x15, 0x14, 0x14, 0x14, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x3D, 0x3D, 0x3D, 0x15, 0x15, 0x15, 0x14, 0x14, 0x14, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x3E, 0x3E, 0x3E, 0x15, 0x15, 0x15, 0x14, 0x14, 0x14, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x3E, 0x3E, 0x3E, 0x15, 0x15, 0x15, 0x14, 0x14, 0x14, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x3E, 0x3E, 0x3E, 0x16, 0x16, 0x16, 0x14, 0x14, 0x14, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x3F, 0x3F, 0x3F, 0x15, 0x15, 0x15, 0x15, 0x15, 0x15, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x3F, 0x3F, 0x3F, 0x15, 0x15, 0x15, 0x15, 0x15, 0x15, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x3F, 0x3F, 0x3F, 0x16, 0x16, 0x16, 0x15, 0x15, 0x15, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x40, 0x40, 0x40, 0x15, 0x15, 0x15, 0x15, 0x15, 0x15, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x40, 0x40, 0x40, 0x16, 0x16, 0x16, 0x15, 0x15, 0x15, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x40, 0x40, 0x40, 0x16, 0x16, 0x16, 0x15, 0x15, 0x15, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x41, 0x41, 0x41, 0x16, 0x16, 0x16, 0x15, 0x15, 0x15, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x41, 0x41, 0x41, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x41, 0x41, 0x41, 0x17, 0x17, 0x17, 0x15, 0x15, 0x15, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x42, 0x42, 0x42, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x42, 0x42, 0x42, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x42, 0x42, 0x42, 0x17, 0x17, 0x17, 0x16, 0x16, 0x16, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x43, 0x43, 0x43, 0x17, 0x17, 0x17, 0x16, 0x16, 0x16, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x43, 0x43, 0x43, 0x17, 0x17, 0x17, 0x16, 0x16, 0x16, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x44, 0x44, 0x44, 0x17, 0x17, 0x17, 0x16, 0x16, 0x16, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x44, 0x44, 0x44, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x44, 0x44, 0x44, 0x18, 0x18, 0x18, 0x16, 0x16, 0x16, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x45, 0x45, 0x45, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x45, 0x45, 0x45, 0x18, 0x18, 0x18, 0x16, 0x16, 0x16, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x45, 0x45, 0x45, 0x18, 0x18, 0x18, 0x17, 0x17, 0x17, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x46, 0x46, 0x46, 0x18, 0x18, 0x18, 0x17, 0x17, 0x17, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x46, 0x46, 0x46, 0x18, 0x18, 0x18, 0x17, 0x17, 0x17, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x46, 0x46, 0x46, 0x19, 0x19, 0x19, 0x17, 0x17, 0x17, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x47, 0x47, 0x47, 0x18, 0x18, 0x18, 0x17, 0x17, 0x17, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x47, 0x47, 0x47, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x47, 0x47, 0x47, 0x19, 0x19, 0x19, 0x17, 0x17, 0x17, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x48, 0x48, 0x48, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x48, 0x48, 0x48, 0x19, 0x19, 0x19, 0x18, 0x18, 0x18, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x49, 0x49, 0x49, 0x18, 0x18, 0x18, 0x18, 0x18, 0x18, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x49, 0x49, 0x49, 0x19, 0x19, 0x19, 0x18, 0x18, 0x18, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x49, 0x49, 0x49, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x4A, 0x4A, 0x4A, 0x19, 0x19, 0x19, 0x18, 0x18, 0x18, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x4A, 0x4A, 0x4A, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x4A, 0x4A, 0x4A, 0x1A, 0x1A, 0x1A, 0x18, 0x18, 0x18, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x4B, 0x4B, 0x4B, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x4B, 0x4B, 0x4B, 0x1A, 0x1A, 0x1A, 0x19, 0x19, 0x19, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x4C, 0x4C, 0x4C, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x4C, 0x4C, 0x4C, 0x1A, 0x1A, 0x1A, 0x19, 0x19, 0x19, },
	{ 0xB8, 0x15, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xCA, 0x8C, 0x06, 0x45, 0x3C, 0x6F, 0x4C, 0x4C, 0x4C, 0x1A, 0x1A, 0x1A, 0x19, 0x19, 0x19, },
};

static u8 elvss_table[14][2] = {
	{ 0xDC, 0x16, },
	{ 0xDC, 0x17, },
	{ 0xDC, 0x18, },
	{ 0xDC, 0x19, },
	{ 0xDC, 0x1A, },
	{ 0xDC, 0x1B, },
	{ 0xDC, 0x1C, },
	{ 0xDC, 0x1D, },
	{ 0xDC, 0x1E, },
	{ 0xDC, 0x1F, },
	{ 0xDC, 0x20, },
	{ 0xDC, 0x21, },
	{ 0xDC, 0x22, },
	{ 0xDC, 0x20, },
};

static u8 vint_array_revH[5] = {
	0x26, /*  HBM(700nit) */
	0x25, /*  675nit */
	0x25, /*  650nit */
	0x24, /*  625nit */
	0x23, /*  600~2nit */
};


struct s6e3ha8 {
	struct backlight_device *bl_dev;
	struct drm_panel panel;
	struct mipi_dsi_device *dsi;
	struct drm_dsc_config dsc;
	struct gpio_desc *reset_gpio;
	struct regulator_bulk_data *supplies;
};

static const struct regulator_bulk_data s6e3ha8_supplies[] = {
	{ .supply = "vdd3" },
	{ .supply = "vci" },
	{ .supply = "vddr" },
};

static inline
struct s6e3ha8 *to_s6e3ha8_amb577px01_wqhd(struct drm_panel *panel)
{
	return container_of(panel, struct s6e3ha8, panel);
}

#define s6e3ha8_test_key_on_lvl2(ctx) \
	mipi_dsi_dcs_write_seq_multi(ctx, 0xf0, 0x5a, 0x5a)
#define s6e3ha8_test_key_off_lvl2(ctx) \
	mipi_dsi_dcs_write_seq_multi(ctx, 0xf0, 0xa5, 0xa5)
#define s6e3ha8_test_key_on_lvl3(ctx) \
	mipi_dsi_dcs_write_seq_multi(ctx, 0xfc, 0x5a, 0x5a)
#define s6e3ha8_test_key_off_lvl3(ctx) \
	mipi_dsi_dcs_write_seq_multi(ctx, 0xfc, 0xa5, 0xa5)
#define s6e3ha8_test_key_on_lvl1(ctx) \
	mipi_dsi_dcs_write_seq_multi(ctx, 0x9f, 0xa5, 0xa5)
#define s6e3ha8_test_key_off_lvl1(ctx) \
	mipi_dsi_dcs_write_seq_multi(ctx, 0x9f, 0x5a, 0x5a)
#define s6e3ha8_afc_off(ctx) \
	mipi_dsi_dcs_write_seq_multi(ctx, 0xe2, 0x00, 0x00)

static void s6e3ha8_amb577px01_wqhd_reset(struct s6e3ha8 *priv)
{
	gpiod_set_value_cansleep(priv->reset_gpio, 1);
	usleep_range(5000, 6000);
	gpiod_set_value_cansleep(priv->reset_gpio, 0);
	usleep_range(5000, 6000);
	gpiod_set_value_cansleep(priv->reset_gpio, 1);
	usleep_range(5000, 6000);
}

static int s6e3ha8_amb577px01_wqhd_on(struct s6e3ha8 *priv)
{
	struct mipi_dsi_device *dsi = priv->dsi;
	struct mipi_dsi_multi_context ctx = { .dsi = dsi };

	dsi->mode_flags |= MIPI_DSI_MODE_LPM;

	s6e3ha8_test_key_on_lvl1(&ctx);

	s6e3ha8_test_key_on_lvl2(&ctx);
	mipi_dsi_compression_mode_multi(&ctx, true);
	s6e3ha8_test_key_off_lvl2(&ctx);

	mipi_dsi_dcs_exit_sleep_mode_multi(&ctx);
	usleep_range(5000, 6000);

	s6e3ha8_test_key_on_lvl2(&ctx);
	mipi_dsi_dcs_write_seq_multi(&ctx, 0xf2, 0x13);
	s6e3ha8_test_key_off_lvl2(&ctx);
	usleep_range(10000, 11000);

	s6e3ha8_test_key_on_lvl2(&ctx);
	mipi_dsi_dcs_write_seq_multi(&ctx, 0xf2, 0x13);
	s6e3ha8_test_key_off_lvl2(&ctx);

	/* OMOK setting 1 (Initial setting) - Scaler Latch Setting Guide */
	s6e3ha8_test_key_on_lvl2(&ctx);
	mipi_dsi_dcs_write_seq_multi(&ctx, 0xb0, 0x07);
	/* latch setting 1 : Scaler on/off & address setting & PPS setting -> Image update latch */
	mipi_dsi_dcs_write_seq_multi(&ctx, 0xf2, 0x3c, 0x10);
	mipi_dsi_dcs_write_seq_multi(&ctx, 0xb0, 0x0b);
	/* latch setting 2 : Ratio change mode -> Image update latch */
	mipi_dsi_dcs_write_seq_multi(&ctx, 0xf2, 0x30);
	/* OMOK setting 2 - Seamless setting guide : WQHD */
	mipi_dsi_dcs_write_seq_multi(&ctx, 0x2a, 0x00, 0x00, 0x05, 0x9f); /* CASET */
	mipi_dsi_dcs_write_seq_multi(&ctx, 0x2b, 0x00, 0x00, 0x0b, 0x8f); /* PASET */
	mipi_dsi_dcs_write_seq_multi(&ctx, 0xba, 0x01); /* scaler setup : scaler off */
	s6e3ha8_test_key_off_lvl2(&ctx);

	mipi_dsi_dcs_write_seq_multi(&ctx, 0x35, 0x00); /* TE Vsync ON */

	s6e3ha8_test_key_on_lvl2(&ctx);
	mipi_dsi_dcs_write_seq_multi(&ctx, 0xed, 0x4c); /* ERR_FG */
	s6e3ha8_test_key_off_lvl2(&ctx);

	s6e3ha8_test_key_on_lvl3(&ctx);
	/* FFC Setting 897.6Mbps */
	mipi_dsi_dcs_write_seq_multi(&ctx, 0xc5, 0x0d, 0x10, 0xb4, 0x3e, 0x01);
	s6e3ha8_test_key_off_lvl3(&ctx);

	s6e3ha8_test_key_on_lvl2(&ctx);
	mipi_dsi_dcs_write_seq_multi(&ctx, 0xb9,
				   0x00, 0xb0, 0x81, 0x09, 0x00, 0x00, 0x00,
				   0x11, 0x03); /* TSP HSYNC Setting */
	s6e3ha8_test_key_off_lvl2(&ctx);

	s6e3ha8_test_key_on_lvl2(&ctx);
	mipi_dsi_dcs_write_seq_multi(&ctx, 0xb0, 0x03);
	mipi_dsi_dcs_write_seq_multi(&ctx, 0xf6, 0x43);
	s6e3ha8_test_key_off_lvl2(&ctx);

	s6e3ha8_test_key_on_lvl2(&ctx);
	/* Brightness condition set */
	mipi_dsi_dcs_write_seq_multi(&ctx, 0xca,
				   0x07, 0x00, 0x00, 0x00, 0x80, 0x80, 0x80,
				   0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80,
				   0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80,
				   0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80,
				   0x80, 0x80, 0x80, 0x00, 0x00, 0x00);
	mipi_dsi_dcs_write_seq_multi(&ctx, 0xb1, 0x00, 0x0c); /* AID Set : 0% */
	mipi_dsi_dcs_write_seq_multi(&ctx, 0xb5,
				   0x19, 0xdc, 0x16, 0x01, 0x34, 0x67, 0x9a,
				   0xcd, 0x01, 0x22, 0x33, 0x44, 0x00, 0x00,
				   0x05, 0x55, 0xcc, 0x0c, 0x01, 0x11, 0x11,
				   0x10); /* MPS/ELVSS Setting */
	mipi_dsi_dcs_write_seq_multi(&ctx, 0xf4, 0xeb, 0x28); /* VINT */
	mipi_dsi_dcs_write_seq_multi(&ctx, 0xf7, 0x03); /* Gamma, LTPS(AID) update */
	s6e3ha8_test_key_off_lvl2(&ctx);

	s6e3ha8_test_key_off_lvl1(&ctx);

	return ctx.accum_err;
}

static int s6e3ha8_enable(struct drm_panel *panel)
{
	struct s6e3ha8 *priv = to_s6e3ha8_amb577px01_wqhd(panel);
	struct mipi_dsi_device *dsi = priv->dsi;
	struct mipi_dsi_multi_context ctx = { .dsi = dsi };

	s6e3ha8_test_key_on_lvl1(&ctx);
	mipi_dsi_dcs_set_display_on_multi(&ctx);
	s6e3ha8_test_key_off_lvl1(&ctx);

	return ctx.accum_err;
}

static int s6e3ha8_disable(struct drm_panel *panel)
{
	struct s6e3ha8 *priv = to_s6e3ha8_amb577px01_wqhd(panel);
	struct mipi_dsi_device *dsi = priv->dsi;
	struct mipi_dsi_multi_context ctx = { .dsi = dsi };

	s6e3ha8_test_key_on_lvl1(&ctx);
	mipi_dsi_dcs_set_display_off_multi(&ctx);
	s6e3ha8_test_key_off_lvl1(&ctx);
	mipi_dsi_msleep(&ctx, 20);

	s6e3ha8_test_key_on_lvl2(&ctx);
	s6e3ha8_afc_off(&ctx);
	s6e3ha8_test_key_off_lvl2(&ctx);

	mipi_dsi_msleep(&ctx, 160);

	return ctx.accum_err;
}

static int s6e3ha8_amb577px01_wqhd_prepare(struct drm_panel *panel)
{
	struct s6e3ha8 *priv = to_s6e3ha8_amb577px01_wqhd(panel);
	struct mipi_dsi_device *dsi = priv->dsi;
	struct mipi_dsi_multi_context ctx = { .dsi = dsi };
	struct drm_dsc_picture_parameter_set pps;
	int ret;

	ret = regulator_bulk_enable(ARRAY_SIZE(s6e3ha8_supplies), priv->supplies);
	if (ret < 0)
		return ret;
	mipi_dsi_msleep(&ctx, 120);
	s6e3ha8_amb577px01_wqhd_reset(priv);

	ret = s6e3ha8_amb577px01_wqhd_on(priv);
	if (ret < 0) {
		gpiod_set_value_cansleep(priv->reset_gpio, 1);
		goto err;
	}

	drm_dsc_pps_payload_pack(&pps, &priv->dsc);

	s6e3ha8_test_key_on_lvl1(&ctx);
	mipi_dsi_picture_parameter_set_multi(&ctx, &pps);
	s6e3ha8_test_key_off_lvl1(&ctx);

	mipi_dsi_msleep(&ctx, 28);

	return ctx.accum_err;
err:
	regulator_bulk_disable(ARRAY_SIZE(s6e3ha8_supplies), priv->supplies);
	return ret;
}

static int s6e3ha8_amb577px01_wqhd_unprepare(struct drm_panel *panel)
{
	struct s6e3ha8 *priv = to_s6e3ha8_amb577px01_wqhd(panel);

	return regulator_bulk_disable(ARRAY_SIZE(s6e3ha8_supplies), priv->supplies);
}

static const struct drm_display_mode s6e3ha8_amb577px01_wqhd_mode = {
	.clock = (1440 + 116 + 44 + 120) * (2960 + 120 + 80 + 124) * 60 / 1000,
	.hdisplay = 1440,
	.hsync_start = 1440 + 116,
	.hsync_end = 1440 + 116 + 44,
	.htotal = 1440 + 116 + 44 + 120,
	.vdisplay = 2960,
	.vsync_start = 2960 + 120,
	.vsync_end = 2960 + 120 + 80,
	.vtotal = 2960 + 120 + 80 + 124,
	.width_mm = 64,
	.height_mm = 132,
};

static int s6e3ha8_amb577px01_wqhd_get_modes(struct drm_panel *panel,
					     struct drm_connector *connector)
{
	return drm_connector_helper_get_modes_fixed(connector, &s6e3ha8_amb577px01_wqhd_mode);
}

#define S6E3HA8_MIN_BRIGHTNESS		0
#define S6E3HA8_MAX_BRIGHTNESS		100
#define S6E3HA8_DEFAULT_BRIGHTNESS	80


static void s6e3ha8_aor(struct mipi_dsi_multi_context *ctx, unsigned index) { /* aka aid */
	u8 data[3] = { 0xB1 };
	memcpy(data + 1, pac_aid_subdivision_data[index], 2);

	mipi_dsi_dcs_write_buffer_multi(ctx, data, 3);
}

#define ACL_15_PERCENT 0x4A
#define ACL_DIMMING_32_FRAME 0x20


static void s6e3ha8_acl(struct mipi_dsi_multi_context *ctx) {
	const u8 acl_dimming_32_frame = 0x20;
	/* ACL OPR Average Setting: 32 frame, Start 50% */
	mipi_dsi_dcs_write_seq_multi(ctx, 0xB4, 0x00, 0x55, 0x40, 0xFF, 0x26, ACL_15_PERCENT, 0x63, 0x55, 0x55, 0x55, 0x3F, 0xB7, 0x12, 0x00, 0x00, ACL_DIMMING_32_FRAME);
	mipi_dsi_dcs_write_seq_multi(ctx, 0x55, 0x02);
}

static void s6e3ha8_elvss(struct mipi_dsi_multi_context *ctx) {
	mipi_dsi_dcs_write_seq_multi(ctx, 0xB5, 0x19, 0xDC, 0x16, 0x01, 0x34, 0x67, 0x9A, 0xCD, 0x01, 0x22, 0x33,
			0x44, 0x00, 0x00, 0x05, 0x55, 0xCC, 0x0C, 0x01, 0x11, 0x11, 0x10, 0x00);
}

static void s6e3ha8_vint(struct mipi_dsi_multi_context *ctx) {
	mipi_dsi_dcs_write_seq_multi(ctx, 0xF4, 0xEB, 0x23);
}

static void s6e3ha8_irc(struct mipi_dsi_multi_context *ctx, unsigned index) {
	mipi_dsi_dcs_write_buffer_multi(ctx, irc_data[index], 36);
}


#define GAMMA_SET_MAX 34
#define LUMINANCE_MAX 74
#define GAMMA_INDEX_MAX 256
#define GRAY_SCALE_MAX 256

// brightness level -> luminance
static unsigned int base_luminance_star_revH[LUMINANCE_MAX][2] = {
	{2,	105},
	{3,	105},
	{4,	105},
	{5,	105},
	{6,	105},
	{7,	105},
	{8,	105},
	{9,	105},
	{10,	105},
	{11,	105},
	{12,	105},
	{13,	105},
	{14,	105},
	{15,	105},
	{16,	105},
	{17,	105},
	{18,	105},
	{19,	105},
	{20,	105},
	{21,	105},
	{23,	105},
	{24,	105},
	{26,	105},
	{27,	105},
	{29,	105},
	{31,	105},
	{33,	105},
	{35,	105},
	{37,	105},
	{39,	105},
	{42,	105},
	{45,	105},
	{48,	105},
	{51,	105},
	{54,	105},
	{57,	105},
	{61,	114},
	{65,	123},
	{69,	126},
	{73,	134},
	{78,	141},
	{83,	151},
	{88,	160},
	{94,	173},
	{100,	184},
	{106,	200},
	{113,	205},
	{120,	219},
	{128,	229},
	{136,	245},
	{145,	253},
	{154,	266},
	{164,	276},
	{174,	295},
	{185,	295},
	{197,	295},
	{210,	295},
	{223,	295},
	{237,	298},
	{253,	307},
	{269,	325},
	{286,	341},
	{301,	347},
	{317,	360},
	{333,	376},
	{340,	390},
	{347,	390},
	{354,	390},
	{362,	390},
	{369,	390},
	{376,	390},
	{384,	390},
	{392,	393},
	{400,	400}
};


static u8 gamma_table[LUMINANCE_MAX][GAMMA_SET_MAX] = {
{0x0, 0x8c, 0xa0, 0x8f, 0x8e, 0x8d, 0x8d, 0x8c, 0x8b, 0x89, 0x8b, 0x8f, 0x8a, 0x8c, 0x97, 0x8b, 0x8a, 0x96, 0x8b, 0x8e, 0xa0, 0x93, 0xa3, 0xb7, 0xa8, 0xa2, 0x9b, 0xa6, 0x42, 0x49, 0x42, 0x0, 0x0, 0x0,},
{0x0, 0x8c, 0xa0, 0x8f, 0x90, 0x8f, 0x8e, 0x8b, 0x8a, 0x88, 0x88, 0x8b, 0x87, 0x89, 0x91, 0x88, 0x89, 0x93, 0x8a, 0x8f, 0x9c, 0x8f, 0xaa, 0xb3, 0xa5, 0xa3, 0x98, 0xa4, 0x4a, 0x51, 0x4a, 0x0, 0x0, 0x0,},
{0x0, 0x8c, 0xa0, 0x8f, 0x8f, 0x8d, 0x8e, 0x8b, 0x89, 0x88, 0x87, 0x8b, 0x86, 0x8b, 0x91, 0x88, 0x8b, 0x93, 0x89, 0x8e, 0x9b, 0x8f, 0xab, 0xb2, 0xa4, 0xa3, 0x98, 0xa4, 0x4c, 0x54, 0x4c, 0x0, 0x0, 0x0,},
{0x0, 0x8e, 0xa0, 0x90, 0x8e, 0x8d, 0x8d, 0x8b, 0x89, 0x88, 0x86, 0x89, 0x86, 0x89, 0x8f, 0x87, 0x89, 0x8f, 0x87, 0x8d, 0x98, 0x8d, 0xac, 0xb1, 0xa3, 0xa3, 0x98, 0x9d, 0x50, 0x57, 0x50, 0x0, 0x0, 0x0,},
{0x0, 0x8e, 0xa0, 0x91, 0x8d, 0x8d, 0x8c, 0x8a, 0x89, 0x88, 0x86, 0x89, 0x85, 0x88, 0x90, 0x87, 0x8b, 0x8e, 0x86, 0x8e, 0x97, 0x8d, 0xab, 0xb0, 0xa3, 0xa3, 0x98, 0x9c, 0x52, 0x59, 0x52, 0x0, 0x0, 0x0,},
{0x0, 0x8e, 0xa0, 0x91, 0x8c, 0x8c, 0x8b, 0x8c, 0x8a, 0x8b, 0x85, 0x89, 0x84, 0x88, 0x8f, 0x86, 0x8c, 0x8d, 0x86, 0x8e, 0x98, 0x8e, 0xac, 0xaf, 0xa1, 0xa2, 0x98, 0x9c, 0x54, 0x5b, 0x54, 0x0, 0x0, 0x0,},
{0x0, 0x8e, 0xa0, 0x91, 0x8d, 0x8c, 0x8c, 0x8b, 0x88, 0x89, 0x87, 0x88, 0x85, 0x88, 0x8f, 0x86, 0x8b, 0x8d, 0x86, 0x8f, 0x97, 0x8d, 0xae, 0xb0, 0xa2, 0xa3, 0x98, 0x9b, 0x54, 0x5b, 0x54, 0x0, 0x0, 0x0,},
{0x0, 0x8f, 0xa0, 0x91, 0x8d, 0x8c, 0x8c, 0x8a, 0x88, 0x89, 0x87, 0x88, 0x85, 0x89, 0x8f, 0x86, 0x8b, 0x8d, 0x86, 0x8f, 0x96, 0x8c, 0xad, 0xaf, 0x9e, 0xa3, 0x98, 0x9c, 0x54, 0x5b, 0x54, 0x0, 0x0, 0x0,},
{0x0, 0x90, 0xa1, 0x92, 0x8c, 0x8c, 0x8c, 0x8b, 0x88, 0x89, 0x87, 0x88, 0x85, 0x88, 0x8d, 0x85, 0x8b, 0x8d, 0x84, 0x90, 0x96, 0x8c, 0xaf, 0xad, 0xa1, 0xa3, 0x98, 0xa4, 0x56, 0x5e, 0x56, 0x0, 0x0, 0x0,},
{0x0, 0x90, 0xa1, 0x92, 0x8c, 0x8c, 0x8c, 0x8b, 0x88, 0x89, 0x87, 0x88, 0x85, 0x89, 0x8f, 0x86, 0x8c, 0x8d, 0x85, 0x92, 0x97, 0x8d, 0xb1, 0xad, 0x9f, 0xa3, 0x98, 0x9a, 0x54, 0x5b, 0x54, 0x0, 0x0, 0x0,},
{0x0, 0x90, 0xa1, 0x92, 0x8d, 0x8d, 0x8d, 0x8b, 0x89, 0x88, 0x86, 0x89, 0x85, 0x89, 0x90, 0x86, 0x8d, 0x8c, 0x85, 0x93, 0x97, 0x8d, 0xb2, 0xad, 0xa1, 0xa3, 0x98, 0xa4, 0x54, 0x5b, 0x54, 0x0, 0x0, 0x0,},
{0x0, 0x90, 0xa1, 0x92, 0x8d, 0x8d, 0x8d, 0x8b, 0x89, 0x88, 0x87, 0x89, 0x86, 0x8a, 0x90, 0x86, 0x8c, 0x8e, 0x86, 0x93, 0x97, 0x8c, 0xb4, 0xae, 0xa2, 0xa3, 0x9b, 0x99, 0x52, 0x59, 0x52, 0x0, 0x0, 0x0,},
{0x0, 0x90, 0xa1, 0x93, 0x8e, 0x8d, 0x8d, 0x8a, 0x89, 0x88, 0x88, 0x89, 0x87, 0x88, 0x8f, 0x85, 0x8d, 0x8e, 0x86, 0x95, 0x97, 0x8d, 0xb5, 0xae, 0xa2, 0xa3, 0x98, 0x99, 0x52, 0x59, 0x52, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa1, 0x93, 0x8e, 0x8d, 0x8d, 0x8a, 0x89, 0x88, 0x88, 0x8a, 0x87, 0x8a, 0x8f, 0x84, 0x8e, 0x8f, 0x87, 0x94, 0x97, 0x8b, 0xb6, 0xb0, 0xa3, 0xa3, 0x98, 0x99, 0x52, 0x59, 0x52, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa1, 0x93, 0x8d, 0x8c, 0x8c, 0x8b, 0x8a, 0x8a, 0x87, 0x89, 0x87, 0x89, 0x8f, 0x86, 0x8d, 0x8e, 0x86, 0x94, 0x96, 0x8b, 0xb5, 0xae, 0xa3, 0xa3, 0x98, 0x98, 0x52, 0x59, 0x52, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa1, 0x93, 0x8e, 0x8c, 0x8d, 0x8b, 0x8a, 0x8a, 0x86, 0x89, 0x85, 0x8a, 0x90, 0x86, 0x8c, 0x8d, 0x85, 0x94, 0x95, 0x8b, 0xb4, 0xae, 0xa1, 0xa3, 0x98, 0x98, 0x54, 0x5b, 0x54, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa1, 0x93, 0x8e, 0x8c, 0x8d, 0x8a, 0x8a, 0x8a, 0x87, 0x89, 0x85, 0x89, 0x8e, 0x85, 0x8c, 0x8d, 0x85, 0x94, 0x96, 0x89, 0xb2, 0xad, 0x9f, 0xa2, 0x98, 0x99, 0x56, 0x5e, 0x56, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa1, 0x93, 0x8e, 0x8c, 0x8d, 0x8a, 0x8a, 0x8a, 0x86, 0x88, 0x84, 0x89, 0x8d, 0x85, 0x8c, 0x8e, 0x86, 0x92, 0x94, 0x88, 0xb2, 0xac, 0xa1, 0xa3, 0x98, 0xa4, 0x56, 0x5e, 0x56, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa1, 0x93, 0x8e, 0x8c, 0x8d, 0x8a, 0x8a, 0x8a, 0x87, 0x88, 0x85, 0x88, 0x8d, 0x85, 0x8c, 0x8d, 0x85, 0x91, 0x94, 0x88, 0xb1, 0xaa, 0x9f, 0xa3, 0x9b, 0x99, 0x56, 0x5e, 0x56, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa0, 0x93, 0x8e, 0x8c, 0x8d, 0x8a, 0x88, 0x89, 0x89, 0x88, 0x86, 0x87, 0x8c, 0x84, 0x8b, 0x8c, 0x85, 0x92, 0x95, 0x88, 0xb0, 0xab, 0x9f, 0xa3, 0x98, 0x97, 0x58, 0x60, 0x58, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa0, 0x94, 0x8d, 0x8c, 0x8c, 0x8b, 0x88, 0x89, 0x87, 0x88, 0x86, 0x87, 0x8c, 0x82, 0x8a, 0x8c, 0x86, 0x90, 0x92, 0x88, 0xaf, 0xaa, 0x9d, 0xa3, 0x98, 0x97, 0x5b, 0x62, 0x5b, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa0, 0x94, 0x8d, 0x8c, 0x8c, 0x8b, 0x88, 0x89, 0x87, 0x88, 0x86, 0x87, 0x8c, 0x83, 0x8a, 0x8b, 0x85, 0x8f, 0x93, 0x88, 0xb0, 0xa9, 0x9e, 0xa3, 0x98, 0x97, 0x5b, 0x62, 0x5b, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa0, 0x94, 0x8d, 0x8c, 0x8c, 0x8c, 0x88, 0x8a, 0x85, 0x87, 0x84, 0x87, 0x8b, 0x83, 0x8b, 0x8b, 0x85, 0x8d, 0x92, 0x87, 0xae, 0xa8, 0x9c, 0xa3, 0x98, 0x97, 0x5d, 0x64, 0x5d, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa0, 0x94, 0x8d, 0x8c, 0x8c, 0x8c, 0x88, 0x8a, 0x85, 0x87, 0x84, 0x87, 0x8b, 0x83, 0x8a, 0x8a, 0x84, 0x8d, 0x91, 0x87, 0xad, 0xa8, 0x9c, 0xa3, 0x98, 0x97, 0x5d, 0x64, 0x5d, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa0, 0x94, 0x8d, 0x8c, 0x8c, 0x8b, 0x87, 0x89, 0x87, 0x86, 0x86, 0x86, 0x89, 0x83, 0x88, 0x8b, 0x84, 0x8c, 0x90, 0x86, 0xad, 0xa6, 0x9b, 0xa3, 0x98, 0x97, 0x60, 0x67, 0x60, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa0, 0x94, 0x8d, 0x8b, 0x8b, 0x8c, 0x88, 0x89, 0x86, 0x85, 0x85, 0x86, 0x89, 0x83, 0x88, 0x8a, 0x84, 0x8b, 0x8f, 0x86, 0xab, 0xa5, 0x99, 0xa3, 0x98, 0x97, 0x63, 0x69, 0x62, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa0, 0x94, 0x8d, 0x8b, 0x8b, 0x8c, 0x88, 0x89, 0x86, 0x85, 0x85, 0x86, 0x89, 0x84, 0x87, 0x88, 0x82, 0x8a, 0x8f, 0x86, 0xaa, 0xa4, 0x99, 0xa3, 0x98, 0x97, 0x63, 0x69, 0x62, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa0, 0x94, 0x8d, 0x8b, 0x8b, 0x8c, 0x88, 0x89, 0x86, 0x85, 0x85, 0x85, 0x88, 0x83, 0x87, 0x88, 0x83, 0x8a, 0x8f, 0x86, 0xa9, 0xa3, 0x98, 0xa3, 0x98, 0x98, 0x63, 0x69, 0x62, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa0, 0x94, 0x8e, 0x8b, 0x8c, 0x8b, 0x88, 0x88, 0x86, 0x85, 0x85, 0x85, 0x88, 0x83, 0x87, 0x87, 0x83, 0x8a, 0x8e, 0x86, 0xa6, 0xa2, 0x95, 0xa3, 0x98, 0x98, 0x65, 0x6c, 0x65, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa0, 0x94, 0x8e, 0x8b, 0x8c, 0x8a, 0x88, 0x87, 0x86, 0x85, 0x85, 0x85, 0x88, 0x83, 0x87, 0x88, 0x82, 0x88, 0x8d, 0x86, 0xa6, 0xa0, 0x95, 0xa3, 0x98, 0x98, 0x65, 0x6c, 0x65, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa0, 0x94, 0x8e, 0x8b, 0x8c, 0x8b, 0x88, 0x88, 0x85, 0x85, 0x85, 0x84, 0x87, 0x82, 0x88, 0x88, 0x83, 0x87, 0x8c, 0x86, 0xa3, 0x9f, 0x93, 0xa3, 0x98, 0x9a, 0x68, 0x6f, 0x68, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa0, 0x94, 0x8e, 0x8c, 0x8d, 0x8a, 0x87, 0x88, 0x85, 0x85, 0x85, 0x84, 0x87, 0x82, 0x87, 0x87, 0x83, 0x86, 0x8b, 0x85, 0xa4, 0x9e, 0x94, 0xa3, 0x98, 0x9a, 0x68, 0x6f, 0x68, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa0, 0x94, 0x8f, 0x8d, 0x8e, 0x88, 0x86, 0x86, 0x85, 0x84, 0x84, 0x84, 0x87, 0x83, 0x86, 0x85, 0x81, 0x86, 0x8c, 0x84, 0xa3, 0x9d, 0x92, 0xa3, 0x98, 0x9a, 0x6b, 0x71, 0x6b, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa0, 0x94, 0x8e, 0x8c, 0x8d, 0x8a, 0x87, 0x88, 0x85, 0x85, 0x86, 0x83, 0x86, 0x81, 0x87, 0x85, 0x82, 0x84, 0x8a, 0x83, 0xa2, 0x9e, 0x92, 0xa3, 0x99, 0x9b, 0x6b, 0x71, 0x6b, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa0, 0x94, 0x8f, 0x8d, 0x8e, 0x88, 0x86, 0x86, 0x85, 0x84, 0x85, 0x83, 0x86, 0x81, 0x86, 0x84, 0x81, 0x85, 0x8a, 0x84, 0x9d, 0x9a, 0x8d, 0xa3, 0x96, 0x97, 0x70, 0x75, 0x6f, 0x0, 0x0, 0x0,},
{0x0, 0x91, 0xa0, 0x94, 0x8e, 0x8d, 0x8d, 0x89, 0x86, 0x87, 0x87, 0x86, 0x87, 0x82, 0x84, 0x7f, 0x86, 0x83, 0x81, 0x84, 0x8a, 0x84, 0x9b, 0x98, 0x8c, 0xa3, 0x98, 0x9b, 0x70, 0x75, 0x6f, 0x0, 0x0, 0x0,},
{0x0, 0x97, 0xa5, 0x99, 0x8e, 0x8c, 0x8d, 0x88, 0x86, 0x86, 0x84, 0x83, 0x83, 0x84, 0x86, 0x83, 0x85, 0x83, 0x80, 0x84, 0x8a, 0x84, 0x9a, 0x98, 0x8b, 0xa3, 0x98, 0x9c, 0x70, 0x75, 0x6f, 0x0, 0x0, 0x0,},
{0x0, 0x9b, 0xa8, 0x9e, 0x8c, 0x89, 0x89, 0x8a, 0x88, 0x89, 0x83, 0x83, 0x83, 0x85, 0x86, 0x81, 0x85, 0x83, 0x81, 0x83, 0x88, 0x83, 0x98, 0x97, 0x8a, 0xa0, 0x92, 0x94, 0x75, 0x78, 0x74, 0x0, 0x0, 0x0,},
{0x0, 0x9d, 0xab, 0xa0, 0x8d, 0x8a, 0x8b, 0x8a, 0x88, 0x88, 0x83, 0x83, 0x83, 0x84, 0x85, 0x82, 0x85, 0x84, 0x81, 0x82, 0x87, 0x82, 0x98, 0x96, 0x8a, 0xa3, 0x97, 0x9b, 0x70, 0x75, 0x6f, 0x0, 0x0, 0x0,},
{0x0, 0xa0, 0xae, 0xa2, 0x8c, 0x8a, 0x8b, 0x8a, 0x87, 0x88, 0x83, 0x84, 0x84, 0x84, 0x85, 0x82, 0x85, 0x84, 0x82, 0x82, 0x86, 0x83, 0x98, 0x97, 0x8c, 0xa0, 0x92, 0x95, 0x70, 0x75, 0x6f, 0x0, 0x0, 0x0,},
{0x0, 0xa4, 0xb1, 0xa7, 0x8b, 0x8a, 0x8b, 0x88, 0x87, 0x87, 0x83, 0x82, 0x83, 0x84, 0x87, 0x83, 0x85, 0x83, 0x81, 0x84, 0x87, 0x83, 0x96, 0x95, 0x89, 0xa0, 0x94, 0x99, 0x70, 0x75, 0x6f, 0x0, 0x0, 0x0,},
{0x0, 0xa9, 0xb5, 0xab, 0x8b, 0x89, 0x8a, 0x89, 0x87, 0x86, 0x85, 0x84, 0x85, 0x82, 0x84, 0x80, 0x84, 0x83, 0x82, 0x84, 0x87, 0x83, 0x96, 0x95, 0x8b, 0xa3, 0x98, 0xa4, 0x6b, 0x71, 0x6b, 0x0, 0x0, 0x0,},
{0x0, 0xad, 0xb8, 0xaf, 0x8b, 0x8a, 0x89, 0x88, 0x85, 0x87, 0x84, 0x83, 0x84, 0x83, 0x84, 0x81, 0x84, 0x83, 0x81, 0x83, 0x87, 0x82, 0x95, 0x95, 0x8b, 0xa3, 0x96, 0x9b, 0x6b, 0x71, 0x6b, 0x0, 0x0, 0x0,},
{0x0, 0xb2, 0xbc, 0xb5, 0x8a, 0x89, 0x88, 0x88, 0x87, 0x88, 0x84, 0x83, 0x83, 0x83, 0x84, 0x82, 0x84, 0x82, 0x81, 0x83, 0x88, 0x82, 0x95, 0x94, 0x8b, 0x9f, 0x91, 0x95, 0x70, 0x75, 0x6f, 0x0, 0x0, 0x0,},
{0x0, 0xb7, 0xc0, 0xb9, 0x87, 0x86, 0x86, 0x89, 0x88, 0x89, 0x85, 0x84, 0x84, 0x83, 0x84, 0x81, 0x84, 0x83, 0x82, 0x83, 0x86, 0x82, 0x94, 0x93, 0x8a, 0xa1, 0x94, 0x98, 0x6b, 0x71, 0x6b, 0x0, 0x0, 0x0,},
{0x0, 0xbd, 0xc5, 0xc0, 0x87, 0x86, 0x85, 0x89, 0x86, 0x87, 0x84, 0x83, 0x83, 0x82, 0x83, 0x81, 0x84, 0x84, 0x82, 0x83, 0x86, 0x82, 0x93, 0x92, 0x8a, 0xa1, 0x93, 0x97, 0x6b, 0x71, 0x6b, 0x0, 0x0, 0x0,},
{0x0, 0xc0, 0xc8, 0xc2, 0x87, 0x88, 0x87, 0x87, 0x85, 0x86, 0x84, 0x84, 0x84, 0x82, 0x84, 0x81, 0x83, 0x83, 0x81, 0x84, 0x85, 0x82, 0x92, 0x90, 0x89, 0xa0, 0x93, 0x97, 0x6b, 0x71, 0x6b, 0x0, 0x0, 0x0,},
{0x0, 0xc6, 0xcc, 0xc7, 0x86, 0x87, 0x86, 0x87, 0x85, 0x86, 0x84, 0x82, 0x84, 0x83, 0x84, 0x82, 0x82, 0x83, 0x80, 0x85, 0x86, 0x83, 0x91, 0x90, 0x89, 0xa0, 0x92, 0x96, 0x6b, 0x71, 0x6b, 0x0, 0x0, 0x0,},
{0x0, 0xc8, 0xcf, 0xca, 0x86, 0x87, 0x86, 0x86, 0x85, 0x85, 0x84, 0x83, 0x84, 0x82, 0x83, 0x80, 0x82, 0x82, 0x81, 0x83, 0x85, 0x82, 0x8f, 0x8e, 0x88, 0x9e, 0x92, 0x95, 0x6b, 0x71, 0x6b, 0x0, 0x0, 0x0,},
{0x0, 0xcf, 0xd5, 0xd0, 0x85, 0x86, 0x85, 0x87, 0x85, 0x85, 0x83, 0x82, 0x82, 0x82, 0x83, 0x82, 0x82, 0x82, 0x81, 0x84, 0x84, 0x82, 0x8e, 0x8e, 0x88, 0x9e, 0x91, 0x95, 0x6b, 0x71, 0x6b, 0x0, 0x0, 0x0,},
{0x0, 0xd1, 0xd7, 0xd3, 0x86, 0x87, 0x86, 0x85, 0x84, 0x84, 0x84, 0x82, 0x84, 0x82, 0x82, 0x82, 0x82, 0x82, 0x81, 0x82, 0x83, 0x80, 0x8c, 0x8c, 0x87, 0x9d, 0x91, 0x95, 0x6b, 0x71, 0x6b, 0x0, 0x0, 0x0,},
{0x0, 0xd6, 0xda, 0xd8, 0x86, 0x87, 0x86, 0x85, 0x84, 0x83, 0x83, 0x83, 0x82, 0x82, 0x83, 0x81, 0x82, 0x83, 0x81, 0x82, 0x83, 0x81, 0x8d, 0x8c, 0x87, 0x9d, 0x90, 0x94, 0x6b, 0x71, 0x6b, 0x0, 0x0, 0x0,},
{0x0, 0xd9, 0xde, 0xda, 0x86, 0x86, 0x85, 0x85, 0x84, 0x84, 0x82, 0x81, 0x81, 0x83, 0x82, 0x83, 0x81, 0x83, 0x80, 0x82, 0x83, 0x80, 0x8b, 0x8b, 0x86, 0x99, 0x8d, 0x91, 0x70, 0x75, 0x6f, 0x0, 0x0, 0x0,},
{0x0, 0xdd, 0xe1, 0xde, 0x85, 0x84, 0x84, 0x84, 0x84, 0x84, 0x82, 0x82, 0x82, 0x84, 0x82, 0x82, 0x80, 0x82, 0x7f, 0x83, 0x83, 0x81, 0x88, 0x89, 0x85, 0x9a, 0x8f, 0x92, 0x6b, 0x71, 0x6b, 0x0, 0x0, 0x0,},
{0x0, 0xdd, 0xe1, 0xde, 0x85, 0x84, 0x84, 0x84, 0x84, 0x84, 0x83, 0x82, 0x83, 0x83, 0x82, 0x81, 0x80, 0x82, 0x7f, 0x82, 0x82, 0x80, 0x8a, 0x8a, 0x86, 0x97, 0x8b, 0x90, 0x70, 0x75, 0x6f, 0x0, 0x0, 0x0,},
{0x0, 0xdd, 0xe1, 0xde, 0x85, 0x84, 0x84, 0x84, 0x83, 0x83, 0x83, 0x81, 0x82, 0x83, 0x82, 0x81, 0x7f, 0x81, 0x7e, 0x82, 0x82, 0x81, 0x88, 0x88, 0x84, 0x95, 0x89, 0x8e, 0x75, 0x78, 0x74, 0x0, 0x0, 0x0,},
{0x0, 0xdd, 0xe1, 0xde, 0x85, 0x84, 0x84, 0x84, 0x83, 0x83, 0x83, 0x81, 0x82, 0x82, 0x82, 0x81, 0x80, 0x81, 0x80, 0x82, 0x81, 0x81, 0x86, 0x87, 0x83, 0x91, 0x86, 0x89, 0x7a, 0x7c, 0x7a, 0x0, 0x0, 0x0,},
{0x0, 0xdf, 0xe3, 0xe0, 0x85, 0x84, 0x83, 0x85, 0x83, 0x84, 0x81, 0x82, 0x82, 0x81, 0x81, 0x81, 0x80, 0x80, 0x80, 0x81, 0x81, 0x80, 0x85, 0x86, 0x83, 0x91, 0x85, 0x88, 0x7a, 0x7c, 0x7a, 0x0, 0x0, 0x0,},
{0x0, 0xe0, 0xe4, 0xe1, 0x83, 0x83, 0x84, 0x84, 0x82, 0x82, 0x81, 0x82, 0x82, 0x82, 0x81, 0x82, 0x80, 0x81, 0x80, 0x80, 0x81, 0x7f, 0x84, 0x83, 0x81, 0x8f, 0x84, 0x88, 0x7f, 0x7f, 0x7f, 0x0, 0x0, 0x0,},
{0x0, 0xe4, 0xe8, 0xe5, 0x84, 0x83, 0x83, 0x83, 0x82, 0x83, 0x81, 0x81, 0x82, 0x82, 0x81, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x7f, 0x85, 0x84, 0x83, 0x8b, 0x80, 0x83, 0x7f, 0x7f, 0x7f, 0x0, 0x0, 0x0,},
{0x0, 0xe9, 0xec, 0xea, 0x82, 0x82, 0x82, 0x83, 0x82, 0x83, 0x81, 0x81, 0x81, 0x82, 0x80, 0x81, 0x7f, 0x81, 0x7f, 0x81, 0x81, 0x80, 0x81, 0x80, 0x7e, 0x8c, 0x82, 0x86, 0x7f, 0x7f, 0x7f, 0x0, 0x0, 0x0,},
{0x0, 0xee, 0xf1, 0xee, 0x80, 0x80, 0x80, 0x84, 0x83, 0x83, 0x81, 0x81, 0x81, 0x81, 0x80, 0x81, 0x80, 0x81, 0x80, 0x7f, 0x81, 0x7f, 0x81, 0x7e, 0x7d, 0x8b, 0x81, 0x86, 0x7f, 0x7f, 0x7f, 0x0, 0x0, 0x0,},
{0x0, 0xf1, 0xf3, 0xf1, 0x82, 0x83, 0x83, 0x82, 0x80, 0x80, 0x81, 0x81, 0x82, 0x80, 0x80, 0x80, 0x80, 0x81, 0x7f, 0x80, 0x81, 0x80, 0x82, 0x80, 0x80, 0x88, 0x7f, 0x83, 0x7f, 0x7f, 0x7f, 0x0, 0x0, 0x0,},
{0x0, 0xf4, 0xf5, 0xf5, 0x84, 0x84, 0x84, 0x7f, 0x7f, 0x7f, 0x82, 0x81, 0x81, 0x80, 0x81, 0x81, 0x7e, 0x81, 0x7f, 0x80, 0x7f, 0x7f, 0x81, 0x7f, 0x80, 0x87, 0x7d, 0x82, 0x7f, 0x7f, 0x7f, 0x0, 0x0, 0x0,},
{0x0, 0xf9, 0xfa, 0xfa, 0x83, 0x83, 0x82, 0x80, 0x7e, 0x7f, 0x80, 0x81, 0x80, 0x81, 0x80, 0x81, 0x7e, 0x81, 0x7f, 0x80, 0x7f, 0x7f, 0x80, 0x7e, 0x80, 0x86, 0x7d, 0x81, 0x7f, 0x7f, 0x7f, 0x0, 0x0, 0x0,},
{0x0, 0xfd, 0xfd, 0xfe, 0x81, 0x81, 0x81, 0x7f, 0x7f, 0x7f, 0x80, 0x80, 0x80, 0x80, 0x7f, 0x7f, 0x7f, 0x80, 0x80, 0x7f, 0x7f, 0x7f, 0x80, 0x7d, 0x7f, 0x86, 0x7d, 0x81, 0x7f, 0x7f, 0x7f, 0x0, 0x0, 0x0,},
{0x0, 0xfc, 0xfd, 0xfd, 0x81, 0x81, 0x81, 0x80, 0x7f, 0x7f, 0x7f, 0x7f, 0x7f, 0x80, 0x7f, 0x80, 0x7e, 0x80, 0x7f, 0x7f, 0x7f, 0x7f, 0x80, 0x7d, 0x7f, 0x84, 0x7b, 0x80, 0x7f, 0x7f, 0x7f, 0x0, 0x0, 0x0,},
{0x0, 0xfc, 0xfd, 0xfd, 0x81, 0x81, 0x81, 0x80, 0x7f, 0x7f, 0x7f, 0x7f, 0x7f, 0x80, 0x7f, 0x80, 0x7e, 0x80, 0x7f, 0x7f, 0x7e, 0x7e, 0x7e, 0x7b, 0x7e, 0x86, 0x7d, 0x83, 0x7f, 0x7f, 0x7f, 0x0, 0x0, 0x0,},
{0x0, 0xfc, 0xfd, 0xfd, 0x81, 0x81, 0x81, 0x80, 0x7f, 0x7f, 0x7f, 0x80, 0x7f, 0x81, 0x80, 0x81, 0x7e, 0x80, 0x7f, 0x7e, 0x7e, 0x7e, 0x7d, 0x7a, 0x7d, 0x86, 0x7d, 0x83, 0x7f, 0x7f, 0x7f, 0x0, 0x0, 0x0,},
{0x0, 0xfc, 0xfd, 0xfd, 0x81, 0x81, 0x81, 0x80, 0x7f, 0x7f, 0x7f, 0x80, 0x7f, 0x81, 0x80, 0x81, 0x7d, 0x7f, 0x7e, 0x80, 0x7f, 0x7f, 0x7c, 0x78, 0x7c, 0x85, 0x7e, 0x83, 0x7f, 0x7f, 0x7f, 0x0, 0x0, 0x0,},
{0x0, 0xfb, 0xfd, 0xfc, 0x81, 0x80, 0x81, 0x7f, 0x7e, 0x7e, 0x80, 0x81, 0x80, 0x81, 0x80, 0x81, 0x7e, 0x80, 0x7f, 0x7f, 0x7f, 0x7e, 0x80, 0x81, 0x80, 0x84, 0x83, 0x84, 0x7a, 0x7c, 0x7a, 0x0, 0x0, 0x0,},
{0x0, 0xfc, 0xfd, 0xfd, 0x80, 0x80, 0x80, 0x80, 0x7e, 0x7f, 0x80, 0x81, 0x80, 0x81, 0x80, 0x81, 0x7d, 0x80, 0x7e, 0x80, 0x7f, 0x7f, 0x80, 0x80, 0x80, 0x81, 0x80, 0x80, 0x7f, 0x7f, 0x7f, 0x0, 0x0, 0x0,},
{0x0, 0xfd, 0xfe, 0xfe, 0x80, 0x80, 0x80, 0x80, 0x7f, 0x7f, 0x80, 0x80, 0x80, 0x81, 0x81, 0x81, 0x7d, 0x7f, 0x7e, 0x80, 0x7f, 0x7f, 0x7e, 0x7f, 0x7f, 0x80, 0x7f, 0x7f, 0x7f, 0x7f, 0x7f, 0x0, 0x0, 0x0,},
{0x7, 0x0, 0x0, 0x0, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x0, 0x0, 0x0,},
};

static void s6e3ha8_gamma(struct mipi_dsi_multi_context *ctx, unsigned index) {
	u8 data[1 + GAMMA_SET_MAX] = { 0xCA };
	memcpy(data + 1, gamma_table[index], GAMMA_SET_MAX);
	mipi_dsi_dcs_write_buffer_multi(ctx, data, GAMMA_SET_MAX + 1);
}


static int s6e3ha8_set_brightness(struct backlight_device *bl_dev)
{
	struct s6e3ha8 *s6e3ha8 = bl_get_data(bl_dev);
	unsigned int brightness = bl_dev->props.brightness;
	int ret;

	struct mipi_dsi_multi_context ctx = { .dsi = s6e3ha8->dsi };

	if (brightness < S6E3HA8_MIN_BRIGHTNESS ||
		brightness > bl_dev->props.max_brightness) {
		dev_err(&bl_dev->dev, "Invalid brightness: %u\n", brightness);
		return -EINVAL;
	}

	unsigned index = brightness * 5;
	s6e3ha8_test_key_on_lvl2(&ctx);
	s6e3ha8_test_key_on_lvl3(&ctx);
	s6e3ha8_aor(&ctx, index);
	s6e3ha8_acl(&ctx);
	s6e3ha8_elvss(&ctx);
	s6e3ha8_vint(&ctx);
	s6e3ha8_irc(&ctx, index);
	s6e3ha8_gamma(&ctx, brightness * LUMINANCE_MAX / S6E3HA8_MAX_BRIGHTNESS);
	mipi_dsi_dcs_write_seq_multi(&ctx, 0xf7, 0x03); /* Gamma, LTPS(AID) update */
	mipi_dsi_dcs_write_seq_multi(&ctx, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00);
	s6e3ha8_test_key_off_lvl2(&ctx);
	s6e3ha8_test_key_off_lvl3(&ctx);



//mipi_dsi_dcs_write_seq_multi(&ctx, 0xf0, 0x5a, 0x5a);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xfc, 0x5a, 0x5a);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xb1, 0x0a, 0xd3);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xf0, 0xa5, 0xa5);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xfc, 0xa5, 0xa5);

//mipi_dsi_dcs_write_seq_multi(&ctx, 0xf0, 0x5a, 0x5a);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xfc, 0x5a, 0x5a);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xb4, 0x00, 0x55, 0x40, 0xff, 0x26, 0x4a, 0x63, 0x55, 0x55, 0x55, 0x3f, 0xb7, 0x12, 0x00, 0x00);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0x55, 0x02);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xf0, 0xa5, 0xa5);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xfc, 0xa5, 0xa5);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xf0, 0x5a, 0x5a);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xfc, 0x5a, 0x5a);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xb5, 0x14, 0xcc, 0x17, 0x01, 0x34, 0x67, 0x9a, 0xcd, 0x01, 0x22, 0x33, 0x44, 0x00, 0x00, 0x05, 0x55, 0xcc, 0x0c, 0x01, 0x11, 0x11, 0x10, 0x13);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xf0, 0xa5, 0xa5);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xfc, 0xa5, 0xa5);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xf0, 0x5a, 0x5a);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xfc, 0x5a, 0x5a);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xf4, 0xeb, 0x23);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0x29, 0x01, 0x00, 0x08, 0x00, 0x03, 0xf0, 0xa5, 0xa5);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xfc, 0xa5, 0xa5);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xf0, 0x5a, 0x5a);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xfc, 0x5a, 0x5a);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xb8, 0x15, 0x12, 0x00, 0x00, 0x13, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x69, 0xca, 0x8c, 0x06, 0x45, 0x3c, 0x6f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xf0, 0xa5, 0xa5);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xfc, 0xa5, 0xa5);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xf0, 0x5a, 0x5a);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xfc, 0x5a, 0x5a);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xca, 0x00, 0x8f, 0xa0, 0x91, 0x8d, 0x8c, 0x8c, 0x8a, 0x88, 0x89, 0x87, 0x88, 0x85, 0x89, 0x8f, 0x86, 0x8b, 0x8d, 0x86, 0x8f, 0x96, 0x8c, 0xad, 0xaf, 0x9e, 0xa3, 0x98, 0x9c, 0x54, 0x5b, 0x54, 0x00, 0x00, 0x00);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xf7, 0x03);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xf0, 0xa5, 0xa5);
//mipi_dsi_dcs_write_seq_multi(&ctx, 0xfc, 0xa5, 0xa5);

/*
	s6e3ha2_call_write_func(ret, s6e3ha2_test_key_on_f0(ctx));
	s6e3ha2_call_write_func(ret, s6e3ha2_update_gamma(ctx, brightness));
	s6e3ha2_call_write_func(ret, s6e3ha2_aor_control(ctx));
	s6e3ha2_call_write_func(ret, s6e3ha2_set_vint(ctx));
	s6e3ha2_call_write_func(ret, s6e3ha2_test_key_off_f0(ctx));
*/
	return ctx.accum_err;
}

static const struct backlight_ops s6e3ha8_bl_ops = {
	.update_status = s6e3ha8_set_brightness,
};



static const struct drm_panel_funcs s6e3ha8_amb577px01_wqhd_panel_funcs = {
	.prepare = s6e3ha8_amb577px01_wqhd_prepare,
	.unprepare = s6e3ha8_amb577px01_wqhd_unprepare,
	.get_modes = s6e3ha8_amb577px01_wqhd_get_modes,
	.enable = s6e3ha8_enable,
	.disable = s6e3ha8_disable,
};

static int s6e3ha8_amb577px01_wqhd_probe(struct mipi_dsi_device *dsi)
{
	struct device *dev = &dsi->dev;
	struct s6e3ha8 *priv;
	int ret;

	priv = devm_kzalloc(dev, sizeof(*priv), GFP_KERNEL);
	if (!priv)
		return -ENOMEM;

	ret = devm_regulator_bulk_get_const(dev, ARRAY_SIZE(s6e3ha8_supplies),
				      s6e3ha8_supplies,
				      &priv->supplies);
	if (ret < 0) {
		dev_err(dev, "failed to get regulators: %d\n", ret);
		return ret;
	}

	priv->reset_gpio = devm_gpiod_get(dev, "reset", GPIOD_OUT_HIGH);
	if (IS_ERR(priv->reset_gpio))
		return dev_err_probe(dev, PTR_ERR(priv->reset_gpio),
				     "Failed to get reset-gpios\n");

	priv->bl_dev = backlight_device_register("s6e3ha8", dev, priv,
						&s6e3ha8_bl_ops, NULL);
	if (IS_ERR(priv->bl_dev)) {
		dev_err(dev, "failed to register backlight device\n");
		return PTR_ERR(priv->bl_dev);
	}

	priv->bl_dev->props.max_brightness = S6E3HA8_MAX_BRIGHTNESS;
	priv->bl_dev->props.brightness = S6E3HA8_DEFAULT_BRIGHTNESS;
	priv->bl_dev->props.power = BACKLIGHT_POWER_OFF;


	priv->dsi = dsi;
	mipi_dsi_set_drvdata(dsi, priv);

	dsi->lanes = 4;
	dsi->format = MIPI_DSI_FMT_RGB888;
	dsi->mode_flags = MIPI_DSI_CLOCK_NON_CONTINUOUS |
		MIPI_DSI_MODE_VIDEO_NO_HFP | MIPI_DSI_MODE_VIDEO_NO_HBP |
		MIPI_DSI_MODE_VIDEO_NO_HSA | MIPI_DSI_MODE_NO_EOT_PACKET;

	drm_panel_init(&priv->panel, dev, &s6e3ha8_amb577px01_wqhd_panel_funcs,
		       DRM_MODE_CONNECTOR_DSI);
	priv->panel.prepare_prev_first = true;

	drm_panel_add(&priv->panel);

	/* This panel only supports DSC; unconditionally enable it */
	dsi->dsc = &priv->dsc;

	priv->dsc.dsc_version_major = 1;
	priv->dsc.dsc_version_minor = 1;

	priv->dsc.slice_height = 40;
	priv->dsc.slice_width = 720;
	WARN_ON(1440 % priv->dsc.slice_width);
	priv->dsc.slice_count = 1440 / priv->dsc.slice_width;
	priv->dsc.bits_per_component = 8;
	priv->dsc.bits_per_pixel = 8 << 4; /* 4 fractional bits */
	priv->dsc.block_pred_enable = true;

	ret = mipi_dsi_attach(dsi);
	if (ret < 0) {
		dev_err(dev, "Failed to attach to DSI host: %d\n", ret);
		drm_panel_remove(&priv->panel);
		return ret;
	}

	return 0;
}

static void s6e3ha8_amb577px01_wqhd_remove(struct mipi_dsi_device *dsi)
{
	struct s6e3ha8 *priv = mipi_dsi_get_drvdata(dsi);
	int ret;

	ret = mipi_dsi_detach(dsi);
	if (ret < 0)
		dev_err(&dsi->dev, "Failed to detach from DSI host: %d\n", ret);

	drm_panel_remove(&priv->panel);
	backlight_device_unregister(priv->bl_dev);
}

static const struct of_device_id s6e3ha8_amb577px01_wqhd_of_match[] = {
	{ .compatible = "samsung,s6e3ha8" },
	{ /* sentinel */ }
};
MODULE_DEVICE_TABLE(of, s6e3ha8_amb577px01_wqhd_of_match);

static struct mipi_dsi_driver s6e3ha8_amb577px01_wqhd_driver = {
	.probe = s6e3ha8_amb577px01_wqhd_probe,
	.remove = s6e3ha8_amb577px01_wqhd_remove,
	.driver = {
		.name = "panel-s6e3ha8",
		.of_match_table = s6e3ha8_amb577px01_wqhd_of_match,
	},
};
module_mipi_dsi_driver(s6e3ha8_amb577px01_wqhd_driver);

MODULE_AUTHOR("Dzmitry Sankouski <dsankouski@gmail.com>");
MODULE_DESCRIPTION("DRM driver for S6E3HA8 panel");
MODULE_LICENSE("GPL");
